@@ -205,6 +205,21 @@ class TestParseconfig:
             old.chdir()
         assert config.toxinipath == toxinipath
 
+    def test_explicit_config_path(self, tmpdir):
+        """
+        Test explicitly setting config path, both with and without the filename
+        """
+        path = tmpdir.mkdir('tox_tmp_directory')
+        config_file_path = path.ensure('tox.ini')
+
+        config = parseconfig(['-c', str(config_file_path)])
+        assert config.toxinipath == config_file_path
+
+        # Passing directory of the config file should also be possible
+        # ('tox.ini' filename is assumed)
+        config = parseconfig(['-c', str(path)])
+        assert config.toxinipath == config_file_path
+
 
 def test_get_homedir(monkeypatch):
     monkeypatch.setattr(py.path.local, "_gethomedir",
@@ -854,6 +869,7 @@ class TestConfigTestEnv:
         assert "PATH" in envconfig.passenv
         assert "PIP_INDEX_URL" in envconfig.passenv
         assert "LANG" in envconfig.passenv
+        assert "LANGUAGE" in envconfig.passenv
         assert "LD_LIBRARY_PATH" in envconfig.passenv
         assert "A123A" in envconfig.passenv
         assert "A123B" in envconfig.passenv
@@ -883,6 +899,7 @@ class TestConfigTestEnv:
         assert "PATH" in envconfig.passenv
         assert "PIP_INDEX_URL" in envconfig.passenv
         assert "LANG" in envconfig.passenv
+        assert "LANGUAGE" in envconfig.passenv
         assert "A123A" in envconfig.passenv
         assert "A123B" in envconfig.passenv
 
@@ -935,6 +952,17 @@ class TestConfigTestEnv:
         assert "A1" in env.passenv
         assert "A2" in env.passenv
 
+    def test_passenv_glob_from_global_env(self, tmpdir, newconfig, monkeypatch):
+        monkeypatch.setenv("A1", "a1")
+        monkeypatch.setenv("A2", "a2")
+        monkeypatch.setenv("TOX_TESTENV_PASSENV", "A*")
+        config = newconfig("""
+            [testenv]
+        """)
+        env = config.envconfigs["python"]
+        assert "A1" in env.passenv
+        assert "A2" in env.passenv
+
     def test_changedir_override(self, tmpdir, newconfig):
         config = newconfig("""
             [testenv]
@@ -1047,6 +1075,35 @@ class TestConfigTestEnv:
         assert 'FOO' in env
         assert 'BAR' in env
 
+    @pytest.mark.xfail(raises=AssertionError, reason="issue #301")
+    def test_substitution_env_defaults_issue301(tmpdir, newconfig, monkeypatch):
+        monkeypatch.setenv("IGNORE_STATIC_DEFAULT", "env")
+        monkeypatch.setenv("IGNORE_DYNAMIC_DEFAULT", "env")
+        config = newconfig("""
+            [testenv:py27]
+            passenv =
+                IGNORE_STATIC_DEFAULT
+                USE_STATIC_DEFAULT
+                IGNORE_DYNAMIC_DEFAULT
+                USE_DYNAMIC_DEFAULT
+            setenv =
+                OTHER_VAR=other
+                IGNORE_STATIC_DEFAULT={env:IGNORE_STATIC_DEFAULT:default}
+                USE_STATIC_DEFAULT={env:USE_STATIC_DEFAULT:default}
+                IGNORE_DYNAMIC_DEFAULT={env:IGNORE_DYNAMIC_DEFAULT:{env:OTHER_VAR}+default}
+                USE_DYNAMIC_DEFAULT={env:USE_DYNAMIC_DEFAULT:{env:OTHER_VAR}+default}
+                IGNORE_OTHER_DEFAULT={env:OTHER_VAR:{env:OTHER_VAR}+default}
+                USE_OTHER_DEFAULT={env:NON_EXISTENT_VAR:{env:OTHER_VAR}+default}
+        """)
+        conf = config.envconfigs['py27']
+        env = conf.setenv
+        assert env['IGNORE_STATIC_DEFAULT'] == "env"
+        assert env['USE_STATIC_DEFAULT'] == "default"
+        assert env['IGNORE_OTHER_DEFAULT'] == "other"
+        assert env['USE_OTHER_DEFAULT'] == "other+default"
+        assert env['IGNORE_DYNAMIC_DEFAULT'] == "env"
+        assert env['USE_DYNAMIC_DEFAULT'] == "other+default"
+
     def test_substitution_positional(self, newconfig):
         inisource = """
             [testenv:py27]
@@ -1830,11 +1887,11 @@ class TestIndexServer:
         inisource = """
             [tox]
             indexserver =
-                default = http://pypi.testrun.org
+                default = http://pypi.somewhere.org
                 name1 = whatever
         """
         config = newconfig([], inisource)
-        assert config.indexserver['default'].url == "http://pypi.testrun.org"
+        assert config.indexserver['default'].url == "http://pypi.somewhere.org"
         assert config.indexserver['name1'].url == "whatever"
         config = newconfig(['-i', 'qwe'], inisource)
         assert config.indexserver['default'].url == "qwe"
@@ -1923,6 +1980,11 @@ class TestCmdInvocation:
             'tox.ini': '''
             [tox]
             envlist=py26,py27,py33,pypy,docs
+            description= py27: run py.test on Python 2.7
+                         py33: run py.test on Python 3.6
+                         pypy: publish to pypy
+                         docs: document stuff
+                         notincluded: random extra
 
             [testenv:notincluded]
             changedir = whatever
@@ -1933,11 +1995,94 @@ class TestCmdInvocation:
         })
         result = cmd.run("tox", "-l")
         result.stdout.fnmatch_lines("""
-            *py26*
-            *py27*
-            *py33*
-            *pypy*
-            *docs*
+            py26
+            py27
+            py33
+            pypy
+            docs
+        """)
+
+    def test_listenvs_verbose_description(self, cmd, initproj):
+        initproj('listenvs_verbose_description', filedefs={
+            'tox.ini': '''
+            [tox]
+            envlist=py26,py27,py33,pypy,docs
+            [testenv]
+            description= py26: run py.test on Python 2.6
+                         py27: run py.test on Python 2.7
+                         py33: run py.test on Python 3.3
+                         pypy: publish to pypy
+                         docs: document stuff
+                         notincluded: random extra
+
+            [testenv:notincluded]
+            changedir = whatever
+
+            [testenv:docs]
+            changedir = docs
+            description = let me overwrite that
+            ''',
+        })
+        result = cmd.run("tox", "-lv")
+        result.stdout.fnmatch_lines("""
+            default environments:
+            py26 -> run py.test on Python 2.6
+            py27 -> run py.test on Python 2.7
+            py33 -> run py.test on Python 3.3
+            pypy -> publish to pypy
+            docs -> let me overwrite that
+        """)
+
+    def test_listenvs_all(self, cmd, initproj):
+        initproj('listenvs_all', filedefs={
+            'tox.ini': '''
+            [tox]
+            envlist=py26,py27,py33,pypy,docs
+
+            [testenv:notincluded]
+            changedir = whatever
+
+            [testenv:docs]
+            changedir = docs
+            ''',
+        })
+        result = cmd.run("tox", "-a")
+        result.stdout.fnmatch_lines("""
+            py26
+            py27
+            py33
+            pypy
+            docs
+            notincluded
+        """)
+
+    def test_listenvs_all_verbose_description(self, cmd, initproj):
+        initproj('listenvs_all_verbose_description', filedefs={
+            'tox.ini': '''
+            [tox]
+            envlist={py27,py36}-{windows,linux}
+            [testenv]
+            description= py27: run py.test on Python 2.7
+                         py36: run py.test on Python 3.6
+                         windows: on Windows platform
+                         linux: on Linux platform
+                         docs: generate documentation
+            commands=py.test {posargs}
+
+            [testenv:docs]
+            changedir = docs
+            ''',
+        })
+        result = cmd.run("tox", "-av")
+        result.stdout.fnmatch_lines("""
+            default environments:
+            py27-windows -> run py.test on Python 2.7 on Windows platform
+            py27-linux   -> run py.test on Python 2.7 on Linux platform
+            py36-windows -> run py.test on Python 3.6 on Windows platform
+            py36-linux   -> run py.test on Python 3.6 on Linux platform
+
+            additional environments:
+            docs         -> generate documentation
         """)
 
     def test_config_specific_ini(self, tmpdir, cmd):
