@@ -38,6 +38,7 @@ class TestToxQuickstartMain(object):
                     'Y',         # py33
                     'Y',         # py34
                     'Y',         # py35
+                    'Y',         # py36
                     'Y',         # pypy
                     'N',         # jython
                     'py.test',   # command to run tests
@@ -49,13 +50,13 @@ class TestToxQuickstartMain(object):
         tox._quickstart.main(argv=['tox-quickstart'])
 
         expected_tox_ini = """
-# Tox (http://tox.testrun.org/) is a tool for running tests
+# Tox (https://tox.readthedocs.io/) is a tool for running tests
 # in multiple virtualenvs. This configuration file will run the
 # test suite on all supported python versions. To use it, "pip install tox"
 # and then run "tox" from this directory.
 
 [tox]
-envlist = py26, py27, py32, py33, py34, py35, pypy
+envlist = py26, py27, py32, py33, py34, py35, py36, pypy
 
 [testenv]
 commands = py.test
@@ -79,6 +80,7 @@ deps =
                     'Y',          # py33
                     'Y',          # py34
                     'Y',          # py35
+                    'Y',          # py36
                     'Y',          # pypy
                     'N',          # jython
                     'nosetests',  # command to run tests
@@ -90,13 +92,13 @@ deps =
         tox._quickstart.main(argv=['tox-quickstart'])
 
         expected_tox_ini = """
-# Tox (http://tox.testrun.org/) is a tool for running tests
+# Tox (https://tox.readthedocs.io/) is a tool for running tests
 # in multiple virtualenvs. This configuration file will run the
 # test suite on all supported python versions. To use it, "pip install tox"
 # and then run "tox" from this directory.
 
 [tox]
-envlist = py26, py27, py32, py33, py34, py35, pypy
+envlist = py26, py27, py32, py33, py34, py35, py36, pypy
 
 [testenv]
 commands = nosetests
@@ -120,6 +122,7 @@ deps =
                     'Y',          # py33
                     'Y',          # py34
                     'Y',          # py35
+                    'Y',          # py36
                     'Y',          # pypy
                     'N',          # jython
                     'trial',      # command to run tests
@@ -131,13 +134,13 @@ deps =
         tox._quickstart.main(argv=['tox-quickstart'])
 
         expected_tox_ini = """
-# Tox (http://tox.testrun.org/) is a tool for running tests
+# Tox (https://tox.readthedocs.io/) is a tool for running tests
 # in multiple virtualenvs. This configuration file will run the
 # test suite on all supported python versions. To use it, "pip install tox"
 # and then run "tox" from this directory.
 
 [tox]
-envlist = py26, py27, py32, py33, py34, py35, pypy
+envlist = py26, py27, py32, py33, py34, py35, py36, pypy
 
 [testenv]
 commands = trial
@@ -161,6 +164,7 @@ deps =
                     'Y',          # py33
                     'Y',          # py34
                     'Y',          # py35
+                    'Y',          # py36
                     'Y',          # pypy
                     'N',          # jython
                     'py.test',    # command to run tests
@@ -171,13 +175,13 @@ deps =
         tox._quickstart.main(argv=['tox-quickstart'])
 
         expected_tox_ini = """
-# Tox (http://tox.testrun.org/) is a tool for running tests
+# Tox (https://tox.readthedocs.io/) is a tool for running tests
 # in multiple virtualenvs. This configuration file will run the
 # test suite on all supported python versions. To use it, "pip install tox"
 # and then run "tox" from this directory.
 
 [tox]
-envlist = py26, py27, py32, py33, py34, py35, pypy
+envlist = py26, py27, py32, py33, py34, py35, py36, pypy
 
 [testenv]
 commands = py.test
@@ -204,7 +208,7 @@ deps =
         tox._quickstart.main(argv=['tox-quickstart'])
 
         expected_tox_ini = """
-# Tox (http://tox.testrun.org/) is a tool for running tests
+# Tox (https://tox.readthedocs.io/) is a tool for running tests
 # in multiple virtualenvs. This configuration file will run the
 # test suite on all supported python versions. To use it, "pip install tox"
 # and then run "tox" from this directory.
@@ -237,7 +241,7 @@ deps =
         tox._quickstart.main(argv=['tox-quickstart'])
 
         expected_tox_ini = """
-# Tox (http://tox.testrun.org/) is a tool for running tests
+# Tox (https://tox.readthedocs.io/) is a tool for running tests
 # in multiple virtualenvs. This configuration file will run the
 # test suite on all supported python versions. To use it, "pip install tox"
 # and then run "tox" from this directory.
@@ -270,13 +274,13 @@ deps =
         tox._quickstart.main(argv=['tox-quickstart'])
 
         expected_tox_ini = """
-# Tox (http://tox.testrun.org/) is a tool for running tests
+# Tox (https://tox.readthedocs.io/) is a tool for running tests
 # in multiple virtualenvs. This configuration file will run the
 # test suite on all supported python versions. To use it, "pip install tox"
 # and then run "tox" from this directory.
 
 [tox]
-envlist = py26, py27, py32, py33, py34, py35, pypy, jython
+envlist = py26, py27, py32, py33, py34, py35, py36, pypy, jython
 
 [testenv]
 commands = py.test
@@ -300,6 +304,7 @@ deps =
                     '',   # py33
                     '',   # py34
                     '',   # py35
+                    '',   # py36
                     '',   # pypy
                     '',   # jython
                     '',   # command to run tests
@@ -311,13 +316,13 @@ deps =
         tox._quickstart.main(argv=['tox-quickstart'])
 
         expected_tox_ini = """
-# Tox (http://tox.testrun.org/) is a tool for running tests
+# Tox (https://tox.readthedocs.io/) is a tool for running tests
 # in multiple virtualenvs. This configuration file will run the
 # test suite on all supported python versions. To use it, "pip install tox"
 # and then run "tox" from this directory.
 
 [tox]
-envlist = py26, py27, py32, py33, py34, py35, pypy, jython
+envlist = py26, py27, py32, py33, py34, py35, py36, pypy, jython
 
 [testenv]
 commands = {envpython} setup.py test
@@ -345,6 +350,7 @@ deps =
                     '',   # py33
                     '',   # py34
                     '',   # py35
+                    '',   # py36
                     '',   # pypy
                     '',   # jython
                     '',   # command to run tests
@@ -357,13 +363,13 @@ deps =
         tox._quickstart.main(argv=['tox-quickstart'])
 
         expected_tox_ini = """
-# Tox (http://tox.testrun.org/) is a tool for running tests
+# Tox (https://tox.readthedocs.io/) is a tool for running tests
 # in multiple virtualenvs. This configuration file will run the
 # test suite on all supported python versions. To use it, "pip install tox"
 # and then run "tox" from this directory.
 
 [tox]
-envlist = py26, py27, py32, py33, py34, py35, pypy, jython
+envlist = py26, py27, py32, py33, py34, py35, py36, pypy, jython
 
 [testenv]
 commands = {envpython} setup.py test
@@ -387,7 +393,7 @@ class TestToxQuickstart(object):
             'deps': 'pytest',
         }
         expected_tox_ini = """
-# Tox (http://tox.testrun.org/) is a tool for running tests
+# Tox (https://tox.readthedocs.io/) is a tool for running tests
 # in multiple virtualenvs. This configuration file will run the
 # test suite on all supported python versions. To use it, "pip install tox"
 # and then run "tox" from this directory.
@@ -414,7 +420,7 @@ deps =
             'deps': '',
         }
         expected_tox_ini = """
-# Tox (http://tox.testrun.org/) is a tool for running tests
+# Tox (https://tox.readthedocs.io/) is a tool for running tests
 # in multiple virtualenvs. This configuration file will run the
 # test suite on all supported python versions. To use it, "pip install tox"
 # and then run "tox" from this directory.
@@ -440,7 +446,7 @@ deps =
             'deps': 'Twisted',
         }
         expected_tox_ini = """
-# Tox (http://tox.testrun.org/) is a tool for running tests
+# Tox (https://tox.readthedocs.io/) is a tool for running tests
 # in multiple virtualenvs. This configuration file will run the
 # test suite on all supported python versions. To use it, "pip install tox"
 # and then run "tox" from this directory.
@@ -471,7 +477,7 @@ deps =
             'deps': 'nose',
         }
         expected_tox_ini = """
-# Tox (http://tox.testrun.org/) is a tool for running tests
+# Tox (https://tox.readthedocs.io/) is a tool for running tests
 # in multiple virtualenvs. This configuration file will run the
 # test suite on all supported python versions. To use it, "pip install tox"
 # and then run "tox" from this directory.
