@@ -266,6 +266,40 @@ def test_develop_extras(newmocksession, tmpdir):
     assert expected in l[-1].args
 
 
+def test_env_variables_added_to_needs_reinstall(tmpdir, mocksession, newconfig, monkeypatch):
+    tmpdir.ensure("setup.py")
+    monkeypatch.setenv("TEMP_PASS_VAR", "123")
+    monkeypatch.setenv("TEMP_NOPASS_VAR", "456")
+    config = newconfig([], """
+        [testenv:python]
+        passenv = temp_pass_var
+        setenv =
+            CUSTOM_VAR = 789
+    """)
+
+    venv = VirtualEnv(config.envconfigs['python'], session=mocksession)
+    action = mocksession.newaction(venv, "hello")
+
+    venv._needs_reinstall(tmpdir, action)
+
+    l = mocksession._pcalls
+    assert len(l) == 2
+    env = l[0].env
+
+    # should have access to setenv vars
+    assert 'CUSTOM_VAR' in env
+    assert env['CUSTOM_VAR'] == '789'
+
+    # should have access to passenv vars
+    assert 'TEMP_PASS_VAR' in env
+    assert env['TEMP_PASS_VAR'] == "123"
+
+    # should also have access to full invocation environment,
+    # for backward compatibility, and to match behavior of venv.run_install_command()
+    assert 'TEMP_NOPASS_VAR' in env
+    assert env["TEMP_NOPASS_VAR"] == "456"
+
+
 def test_test_hashseed_is_in_output(newmocksession):
     original_make_hashseed = tox.config.make_hashseed
     tox.config.make_hashseed = lambda: '123456789'
@@ -527,6 +561,39 @@ class TestVenvTest:
         assert 'PIP_REQUIRE_VIRTUALENV' not in os.environ
         assert '__PYVENV_LAUNCHER__' not in os.environ
 
+    def test_pythonpath_usage(self, newmocksession, monkeypatch):
+        monkeypatch.setenv("PYTHONPATH", "/my/awesome/library")
+        mocksession = newmocksession([], """
+            [testenv:python]
+            commands=abc
+        """)
+        venv = mocksession.getenv("python")
+        action = mocksession.newaction(venv, "getenv")
+        venv.run_install_command(['qwe'], action=action)
+        assert 'PYTHONPATH' not in os.environ
+        mocksession.report.expect("warning", "*Discarding $PYTHONPATH from environment*")
+
+        l = mocksession._pcalls
+        assert len(l) == 1
+        assert 'PYTHONPATH' not in l[0].env
+
+        # passenv = PYTHONPATH allows PYTHONPATH to stay in environment
+        monkeypatch.setenv("PYTHONPATH", "/my/awesome/library")
+        mocksession = newmocksession([], """
+            [testenv:python]
+            commands=abc
+            passenv = PYTHONPATH
+        """)
+        venv = mocksession.getenv("python")
+        action = mocksession.newaction(venv, "getenv")
+        venv.run_install_command(['qwe'], action=action)
+        assert 'PYTHONPATH' in os.environ
+        mocksession.report.not_expect("warning", "*Discarding $PYTHONPATH from environment*")
+
+        l = mocksession._pcalls
+        assert len(l) == 2
+        assert l[1].env['PYTHONPATH'] == '/my/awesome/library'
+
 
 def test_env_variables_added_to_pcall(tmpdir, mocksession, newconfig, monkeypatch):
     pkg = tmpdir.ensure("package.tar.gz")
@@ -538,11 +605,11 @@ def test_env_variables_added_to_pcall(tmpdir, mocksession, newconfig, monkeypatc
         passenv = x123
         setenv =
             ENV_VAR = value
+            PYTHONPATH = value
     """)
     mocksession._clearmocks()
 
     venv = VirtualEnv(config.envconfigs['python'], session=mocksession)
-    # import pdb; pdb.set_trace()
     mocksession.installpkg(venv, pkg)
     venv.test()
 
@@ -555,6 +622,8 @@ def test_env_variables_added_to_pcall(tmpdir, mocksession, newconfig, monkeypatc
         assert env['ENV_VAR'] == 'value'
         assert env['VIRTUAL_ENV'] == str(venv.path)
         assert env['X123'] == "123"
+        assert 'PYTHONPATH' in env
+        assert env['PYTHONPATH'] == 'value'
     # all env variables are passed for installation
     assert l[0].env["YY"] == "456"
     assert "YY" not in l[1].env
@@ -562,6 +631,9 @@ def test_env_variables_added_to_pcall(tmpdir, mocksession, newconfig, monkeypatc
     assert set(["ENV_VAR", "VIRTUAL_ENV", "PYTHONHASHSEED", "X123", "PATH"])\
         .issubset(l[1].env)
 
+    # setenv does not trigger PYTHONPATH warnings
+    mocksession.report.not_expect("warning", "*Discarding $PYTHONPATH from environment*")
+
     # for e in os.environ:
     #    assert e in env
 
@@ -610,7 +682,6 @@ def test_run_install_command(newmocksession):
 def test_run_custom_install_command(newmocksession):
     mocksession = newmocksession([], """
         [testenv]
-        commands={envpython} --version
         install_command=easy_install {opts} {packages}
     """)
     venv = mocksession.getenv('python')
@@ -627,7 +698,6 @@ def test_run_custom_install_command(newmocksession):
 def test_command_relative_issue26(newmocksession, tmpdir, monkeypatch):
     mocksession = newmocksession([], """
         [testenv]
-        commands={envpython} --version
     """)
     x = tmpdir.ensure("x")
     venv = mocksession.getenv("python")
@@ -702,14 +772,3 @@ def test_tox_testenv_pre_post(newmocksession):
     assert l == []
     mocksession.runtestenv(venv)
     assert l == ['started', 'finished']
-
-
-def test_error_when_commands_missing(newmocksession):
-    mocksession = newmocksession([], """
-        [testenv]
-    """)
-
-    venv = mocksession.getenv('python')
-    venv.status = None
-    mocksession.runtestenv(venv)
-    assert venv.status == 'nothing to do'
