@@ -351,8 +351,6 @@ def test_venv_special_chars_issue252(cmd, initproj):
         'tox.ini': '''
             [tox]
             envlist = special&&1
-            [testenv]
-            commands={envpython} --version
             [testenv:special&&1]
             changedir=tests
         '''
@@ -470,10 +468,7 @@ def test_package_install_fails(cmd, initproj):
                 install_requires=['qweqwe123'],
                 )
             """,
-        'tox.ini': """
-        [testenv]
-        commands={envpython} --version
-        """,
+        'tox.ini': '',
     })
     result = cmd.run("tox", )
     assert result.ret
@@ -546,8 +541,6 @@ class TestToxRun:
 
 def test_develop(initproj, cmd):
     initproj("example123", filedefs={'tox.ini': """
-        [testenv]
-        commands={envpython} --version
     """})
     result = cmd.run("tox", "-vv", "--develop")
     assert not result.ret
@@ -557,7 +550,6 @@ def test_develop(initproj, cmd):
 def test_usedevelop(initproj, cmd):
     initproj("example123", filedefs={'tox.ini': """
             [testenv]
-            commands={envpython} --version
             usedevelop=True
     """})
     result = cmd.run("tox", "-vv")
@@ -567,8 +559,6 @@ def test_usedevelop(initproj, cmd):
 
 def test_usedevelop_mixed(initproj, cmd):
     initproj("example123", filedefs={'tox.ini': """
-            [testenv]
-            commands={envpython} --version
             [testenv:devenv]
             usedevelop=True
             [testenv:nondev]
@@ -586,8 +576,9 @@ def test_usedevelop_mixed(initproj, cmd):
     assert "sdist-make" in result.stdout.str()
 
 
-def test_test_usedevelop(cmd, initproj):
-    initproj("example123-0.5", filedefs={
+@pytest.mark.parametrize("src_root", [".", "src"])
+def test_test_usedevelop(cmd, initproj, src_root):
+    initproj("example123-0.5", src_root=src_root, filedefs={
         'tests': {
             'test_hello.py': """
                 def test_hello(pytestconfig):
@@ -612,6 +603,7 @@ def test_test_usedevelop(cmd, initproj):
     assert "sdist-make" not in result.stdout.str()
     result = cmd.run("tox", "-epython", )
     assert not result.ret
+    assert "develop-inst-noop" in result.stdout.str()
     result.stdout.fnmatch_lines([
         "*1 passed*",
         "*summary*",
@@ -621,6 +613,7 @@ def test_test_usedevelop(cmd, initproj):
     old = cmd.tmpdir.chdir()
     result = cmd.run("tox", "-c", "example123/tox.ini")
     assert not result.ret
+    assert "develop-inst-noop" in result.stdout.str()
     result.stdout.fnmatch_lines([
         "*1 passed*",
         "*summary*",
@@ -633,11 +626,39 @@ def test_test_usedevelop(cmd, initproj):
     testfile.write("def test_fail(): assert 0")
     result = cmd.run("tox", )
     assert result.ret
+    assert "develop-inst-noop" in result.stdout.str()
     result.stdout.fnmatch_lines([
         "*1 failed*",
         "*summary*",
         "*python: *failed*",
     ])
+    # test develop is called if setup.py changes
+    setup_py = py.path.local("setup.py")
+    setup_py.write(setup_py.read() + ' ')
+    result = cmd.run("tox", )
+    assert result.ret
+    assert "develop-inst-nodeps" in result.stdout.str()
+
+
+def test_alwayscopy(initproj, cmd):
+    initproj("example123", filedefs={'tox.ini': """
+            [testenv]
+            commands={envpython} --version
+            alwayscopy=True
+    """})
+    result = cmd.run("tox", "-vv")
+    assert not result.ret
+    assert "virtualenv --always-copy" in result.stdout.str()
+
+
+def test_alwayscopy_default(initproj, cmd):
+    initproj("example123", filedefs={'tox.ini': """
+            [testenv]
+            commands={envpython} --version
+    """})
+    result = cmd.run("tox", "-vv")
+    assert not result.ret
+    assert "virtualenv --always-copy" not in result.stdout.str()
 
 
 def test_test_piphelp(initproj, cmd):
@@ -658,7 +679,6 @@ def test_notest(initproj, cmd):
     initproj("example123", filedefs={'tox.ini': """
         # content of: tox.ini
         [testenv:py26]
-        commands={envpython} --version
         basepython=python
     """})
     result = cmd.run("tox", "-v", "--notest")
@@ -675,10 +695,7 @@ def test_notest(initproj, cmd):
 
 
 def test_PYC(initproj, cmd, monkeypatch):
-    initproj("example123", filedefs={'tox.ini': """
-        [testenv]
-        commands={envpython} --version
-    """})
+    initproj("example123", filedefs={'tox.ini': ''})
     monkeypatch.setenv("PYTHONDOWNWRITEBYTECODE", 1)
     result = cmd.run("tox", "-v", "--notest")
     assert not result.ret
@@ -688,10 +705,7 @@ def test_PYC(initproj, cmd, monkeypatch):
 
 
 def test_env_VIRTUALENV_PYTHON(initproj, cmd, monkeypatch):
-    initproj("example123", filedefs={'tox.ini': """
-        [testenv]
-        commands={envpython} --version
-    """})
+    initproj("example123", filedefs={'tox.ini': ''})
     monkeypatch.setenv("VIRTUALENV_PYTHON", '/FOO')
     result = cmd.run("tox", "-v", "--notest")
     assert not result.ret, result.stdout.lines
@@ -717,8 +731,6 @@ def test_separate_sdist_no_sdistfile(cmd, initproj):
         'tox.ini': """
             [tox]
             distshare=%s
-            [testenv]
-            commands={envpython} --version
         """ % distshare
     })
     result = cmd.run("tox", "--sdistonly")
@@ -736,8 +748,6 @@ def test_separate_sdist(cmd, initproj):
             [tox]
             distshare=%s
             sdistsrc={distshare}/pkg123-0.7.zip
-            [testenv]
-            commands={envpython} --version
         """ % distshare
     })
     result = cmd.run("tox", "--sdistonly")
@@ -758,8 +768,6 @@ def test_sdist_latest(tmpdir, newconfig):
             [tox]
             distshare=%s
             sdistsrc={distshare}/pkg123-*
-            [testenv]
-            commands={envpython} --version
     """ % distshare)
     p = distshare.ensure("pkg123-1.4.5.zip")
     distshare.ensure("pkg123-1.4.5a1.zip")
@@ -812,7 +820,6 @@ def test_verbosity(cmd, initproj, verbosity):
     initproj("pkgX-0.0.5", filedefs={
         'tox.ini': """
         [testenv]
-        commands={envpython} --version
     """})
     result = cmd.run("tox", verbosity)
     assert result.ret == 0
